<?php

namespace TDevAgency\DeliveriesPayments\Controllers;

use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\View;
use Psr\SimpleCache\InvalidArgumentException;
use TDevAgency\Cms\Controllers\Controller;
use TDevAgency\DeliveriesPayments\Facades\Delivery;
use TDevAgency\DeliveriesPayments\Facades\Payment;
use TDevAgency\Erp\Models\CoreConfig;

final class DeliveryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\View\View
     */
    public function index(): \Illuminate\Contracts\View\View
    {
        $view = View::make('deliveries::index');


        $items = [];

        foreach (Config::get('deliveries_payments.deliveries') as $code => $delivery) {
            $items[] = [
                'code' => $code,
                'label' => Delivery::driver($code)->getLabel(),
                'is_active' => Delivery::driver($code)->isActive()
            ];
        }
        $method = 'deliveries';

        $view->with(compact('items', 'method'));
        return $view;
    }

    /**
     * @param $code
     * @param Request $request
     * @return RedirectResponse|void
     * @throws InvalidArgumentException
     */
    public function update($code, Request $request)
    {
        if (!Config::has('deliveries_payments.deliveries.' . $code)) {
            return abort(404);
        }

        $config = Config::get('deliveries_payments.deliveries.' . $code);
        foreach ($request->all() as $key => $value) {
            if ($key === '_token') {
                continue;
            }

            $suffix = Delivery::driver($code)->getSuffix($key);

            CoreConfig::updateOrCreate([
                'container_id' => Auth::user()->container->id,
                'config_key' => $key,
            ], [
                'container_id' => Auth::user()->container->id,
                'config_key' => $key,
                'config_value' => $value,
                'is_encrypted' => isset($config['encrypted']) && is_array($config['encrypted']) && in_array($suffix, $config['encrypted'])
            ]);
        }

        if (Cache::has('core_config_' . Auth::user()->container->id)) {
            Cache::delete('core_config_' . Auth::user()->container->id);
        }

        return Redirect::route('cms.deliveries.index');
    }

    /**
     * @param $code
     * @return \Illuminate\Contracts\View\View|void
     */
    public function edit($code)
    {

        $view = View::make('payments::single');
        if (!Config::has('deliveries_payments.deliveries.' . $code)) {
            return abort(404);
        }
        $formRoute = route('cms.deliveries.edit', $code);

        $options = Delivery::driver($code)->getAdminOptions();
        return $view->with(compact('options', 'formRoute'));
    }

}
