<?php

namespace TDevAgency\DeliveriesPayments\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\View;
use TDevAgency\Cms\Controllers\Controller;
use TDevAgency\DeliveriesPayments\Facades\Delivery;
use TDevAgency\DeliveriesPayments\Facades\Payment;
use TDevAgency\Erp\Models\CoreConfig;

final class PaymentController extends Controller
{
    public function edit($payment_code)
    {
        $view = View::make('payments::single');
        if (!Config::has('deliveries_payments.payments.' . $payment_code)) {
            return abort(404);
        }
        $formRoute = route('cms.payments.edit', $payment_code);

        $options = Payment::driver($payment_code)->getAdminOptions();
        return $view->with(compact('options', 'formRoute'));
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\View\View
     */
    public function index()
    {
        $view = View::make('payments::index');

        $items = [];

        foreach (Config::get('deliveries_payments.payments') as $code => $payment) {
            $items[] = [
                'code'      => $code,
                'label'     => Payment::driver($code)->getLabel(),
                'is_active' => Payment::driver($code)->isActive()
            ];
        }

        $method = 'payments';

        $view->with(compact('items', 'method'));
        return $view;
    }

    /**
     * @param $payment_code
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse|void
     * @throws \Psr\SimpleCache\InvalidArgumentException
     */
    public function update($payment_code, Request $request)
    {
        if (!Config::has('deliveries_payments.payments.' . $payment_code)) {
            return abort(404);
        }

        $config = Config::get('deliveries_payments.payments.' . $payment_code);
        foreach ($request->all() as $key => $value) {
            if ($key === '_token') {
                continue;
            }
            $suffix = Payment::driver($payment_code)->getSuffix($key);
            CoreConfig::updateOrCreate(
                [
                    'container_id' => Auth::user()->container->id,
                    'config_key'   => $key,
                ],
                [
                    'container_id' => Auth::user()->container->id,
                    'config_key'   => $key,
                    'config_value' => $value,
                    'is_encrypted' => isset($config['encrypted']) && is_array($config['encrypted']) && in_array(
                            $suffix,
                            $config['encrypted']
                        )
                ]
            );
        }

        if (Cache::has('core_config_' . Auth::user()->container->id)) {
            Cache::delete('core_config_' . Auth::user()->container->id);
        }

        return Redirect::route('cms.payments.index');
    }

}
